pub trait SqlxDecode: Sized {
// Required method
fn decode_from_row(row: &SqlxRow, index: usize) -> SqlxResult<Self>;
}Expand description
Trait for decoding values from a row by index.
Required Methods
Sourcefn decode_from_row(row: &SqlxRow, index: usize) -> SqlxResult<Self>
fn decode_from_row(row: &SqlxRow, index: usize) -> SqlxResult<Self>
Decode a value from a row at the given index.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".